CdpEvent class

One protocol event pushed by the endpoint (no request id).

Constructors

CdpEvent(String method, Map<String, Object?> params, {String? sessionId})
Creates an event.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → String
Event method, e.g. Page.screencastFrame.
final
params → Map<String, Object?>
Event parameters.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String?
Flat-session the event belongs to (Target.attachToTarget with flatten: true); null on browser-scoped and page-socket events.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited